combinatorial_designs: Data from the Handbook of Combinatorial Designs
======================================================================

Description
-----------

Data for Combinatorial Designs. Current content:

-  The table of MOLS (10 000 integers) from the Handbook of
   Combinatorial Designs, 2ed.

License
-------

Public domain.


Upstream Contact
----------------

   None

Dependencies
------------

N/A
